Struct
QmiMessageWdsDeleteProfileInput
since: 1.18
Description [src]
struct QmiMessageWdsDeleteProfileInput {
/* No available fields */
}
The QmiMessageWdsDeleteProfileInput structure contains private data and should only be accessed
using the provided API.
Available since: 1.18
Constructors
qmi_message_wds_delete_profile_input_new
Allocates a new QmiMessageWdsDeleteProfileInput.
since: 1.18
Instance methods
qmi_message_wds_delete_profile_input_get_profile_identifier
Get the ‘Profile Identifier’ field from self.
since: 1.18
qmi_message_wds_delete_profile_input_ref
Atomically increments the reference count of self by one.
since: 1.18
qmi_message_wds_delete_profile_input_set_profile_identifier
Set the ‘Profile Identifier’ field in the message.
since: 1.18
qmi_message_wds_delete_profile_input_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.18